var __hasProp=Object.prototype.hasOwnProperty,__extends=function(a,b){function d(){this.constructor=a}for(var c in b)__hasProp.call(b,c)&&(a[c]=b[c]);return d.prototype=b.prototype,a.prototype=new d,a.__super__=b.prototype,a};define(["backbone","cilantro/views"],function(a,b){var c,d,e;return c=function(){function a(){a.__super__.constructor.apply(this,arguments)}return __extends(a,b.Dialog.ItemEditor),a.prototype.initialize=function(){return App.hub.subscribe("object-set/edit",this.editHandler),a.__super__.initialize.apply(this,arguments)},a}(),d=function(){function a(){a.__super__.constructor.apply(this,arguments)}return __extends(a,b.List.Item),a.prototype.className="object-set",a.prototype.edit=function(a,b){return b==null&&(b=this.model),App.hub.publish("object-set/edit",b),!1},a}(),e=function(){function a(){a.__super__.constructor.apply(this,arguments)}return __extends(a,b.List.List),a.prototype.viewClass=d,a.prototype.defaultContent='<section class="info">You have no saved sets.</section>',a}(),{Item:d,List:e,Editor:c}})