var __hasProp=Object.prototype.hasOwnProperty,__extends=function(a,b){function d(){this.constructor=a}for(var c in b)__hasProp.call(b,c)&&(a[c]=b[c]);return d.prototype=b.prototype,a.prototype=new d,a.__super__=b.prototype,a};define(["backbone","common/models/polling"],function(a,b){var c,d;return c=function(a){var b,c,e,f;b=[];for(e=0,f=a.length;e<f;e++)c=a[e],b.push(d(c));return b},d=function(c){var d,e;return e=function(){function b(){b.__super__.constructor.apply(this,arguments)}return __extends(b,a.Model),b.prototype.url=function(){var a;return a=b.__super__.url.apply(this,arguments),/\/$/.test(a)||(a+="/"),a},b.prototype.initialize=function(){return this.bind("change",function(){return App.hub.publish(""+c.name+"/change",this)})},b}(),d=function(){function a(){a.__super__.constructor.apply(this,arguments)}return __extends(a,b.Collection),a.prototype.name=""+c.name+" Sets",a.prototype.url=c.url,a.prototype.model=e,a.prototype.comparator=function(a){return-Number(new Date(a.get("modified")))},a}(),{Model:e,Collection:d}},{createObjectSetClasses:c}})